<?php

/**
 * @file
 * Definition of Drupal\range\Plugin\field\formatter\RangeUnformattedFormatter.
 */

namespace Drupal\range\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;

/**
 * Plugin implementation of the 'range_unformatted' formatter.
 *
 * @FieldFormatter(
 *   id = "range_unformatted",
 *   label = @Translation("Unformatted"),
 *   field_types = {
 *     "range_integer",
 *     "range_decimal",
 *     "range_float"
 *   },
 *   settings = {
 *     "range_separator" = "-"
 *   }
 * )
 */
class RangeUnformattedFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, array &$form_state) {
    $elements['range_separator'] = array(
      '#type' => 'textfield',
      '#title' => t('Range separator.'),
      '#default_value' => $this->getSetting('range_separator'),
      '#weight' => 0,
    );

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = array();
    $from_value = 1234.1234567890;
    $to_value = 4321.0987654321;

    $summary[] = $from_value . $this->getSetting('range_separator') . $to_value;

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items) {
    $elements = array();

    foreach ($items as $delta => $item) {
      $output = $item->from . $this->getSetting('range_separator') . $item->to;

      $elements[$delta] = array('#markup' => $output);
    }

    return $elements;
  }

}
