<?php

/**
 * @file
 * Contains \Drupal\range\Plugin\Field\FieldType\RangeFloatItem.
 */

namespace Drupal\range\Plugin\Field\FieldType;

use Drupal\Core\TypedData\DataDefinition;
use Drupal\Core\Field\FieldDefinitionInterface;

/**
 * Plugin implementation of the 'range_float' field type.
 *
 * @FieldType(
 *   id = "range_float",
 *   label = @Translation("Range (float)"),
 *   description = @Translation("This field stores a float range in the database."),
 *   instance_settings = {
 *     "min" = "",
 *     "max" = "",
 *     "from" = {
 *       "prefix" = "",
 *       "suffix" = ""
 *     },
 *     "to" = {
 *       "prefix" = "",
 *       "suffix" = ""
 *     }
 *   },
 *   default_widget = "range",
 *   default_formatter = "range_decimal"
 * )
 */
class RangeFloatItem extends RangeItemBase {

  /**
   * {@inheritdoc}
   */
  public function getPropertyDefinitions() {
    if (!isset(static::$propertyDefinitions)) {
      static::$propertyDefinitions['from'] = DataDefinition::create('float')
        ->setLabel(t('From value'));
      static::$propertyDefinitions['to'] = DataDefinition::create('float')
        ->setLabel(t('To value'));
    }
    return static::$propertyDefinitions;
  }

  /**
   * {@inheritdoc}
   */
  public function instanceSettingsForm(array $form, array &$form_state) {
    $element = parent::instanceSettingsForm($form, $form_state);

    $element['min']['#step'] = $element['max']['#step'] = 'any';

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldDefinitionInterface $field_definition) {
    return array(
      'columns' => array(
        'from' => array(
          'type' => 'float',
          'not null' => FALSE,
        ),
        'to' => array(
          'type' => 'float',
          'not null' => FALSE,
        ),
      ),
    );
  }

}
