<?php

/**
 * @file
 * Contains \Drupal\range\Plugin\Field\FieldType\RangeIntegerItem.
 */

namespace Drupal\range\Plugin\Field\FieldType;

use Drupal\Core\TypedData\DataDefinition;
use Drupal\Core\Field\FieldDefinitionInterface;

/**
 * Plugin implementation of the 'range_integer' field type.
 *
 * @FieldType(
 *   id = "range_integer",
 *   label = @Translation("Range (integer)"),
 *   description = @Translation("This field stores an integer range in the database."),
 *   instance_settings = {
 *     "min" = "",
 *     "max" = "",
 *     "from" = {
 *       "prefix" = "",
 *       "suffix" = ""
 *     },
 *     "to" = {
 *       "prefix" = "",
 *       "suffix" = ""
 *     }
 *   },
 *   default_widget = "range",
 *   default_formatter = "range_integer"
 * )
 */
class RangeIntegerItem extends RangeItemBase {

  /**
   * {@inheritdoc}
   */
  public function getPropertyDefinitions() {
    if (!isset(static::$propertyDefinitions)) {
      static::$propertyDefinitions['from'] = DataDefinition::create('integer')
        ->setLabel(t('From value'));
      static::$propertyDefinitions['to'] = DataDefinition::create('integer')
        ->setLabel(t('To value'));
    }
    return static::$propertyDefinitions;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldDefinitionInterface $field_definition) {
    return array(
      'columns' => array(
        'from' => array(
          'type' => 'int',
          'not null' => FALSE,
        ),
        'to' => array(
          'type' => 'int',
          'not null' => FALSE,
        ),
      ),
    );
  }

}
