<?php

/**
 * @file
 * Contains \Drupal\range\Plugin\Field\FieldType\RangeItemBase.
 */

namespace Drupal\range\Plugin\Field\FieldType;

use Drupal\Core\Field\ConfigFieldItemBase;

/**
 * Base class for 'range' configurable field types.
 */
abstract class RangeItemBase extends ConfigFieldItemBase {

  /**
   * Definitions of the contained properties.
   *
   * @var array
   */
  static $propertyDefinitions;

  /**
   * {@inheritdoc}
   */
  public function instanceSettingsForm(array $form, array &$form_state) {
    $element = array();
    $settings = $this->getSettings();

    $element['min'] = array(
      '#type' => 'number',
      '#title' => t('Minimum'),
      '#default_value' => $settings['min'],
      '#description' => t('The minimum value that should be allowed in this field. Leave blank for no minimum.'),
    );
    $element['max'] = array(
      '#type' => 'number',
      '#title' => t('Maximum'),
      '#default_value' => $settings['max'],
      '#description' => t('The maximum value that should be allowed in this field. Leave blank for no maximum.'),
    );
    $element += $this->instanceSettingsFormSubElementPrefixSuffix(t('FROM'), 'from');
    $element += $this->instanceSettingsFormSubElementPrefixSuffix(t('TO'), 'to');

    return $element;
  }

  /**
   * Helper method. Builds settings fieldsets for the FROM/TO values.
   *
   * @param string $title
   *  Fieldset title.
   * @param string $element_name
   *  Form element machine name.
   * @return array FROM/TO instance settings fieldset.
   */
  protected function instanceSettingsFormSubElementPrefixSuffix($title, $element_name) {
    $settings = $this->getSettings();

    $element = array();

    $element[$element_name] = array(
      '#type' => 'fieldset',
      '#title' => $title,
    );

    $element[$element_name]['prefix'] = array(
      '#type' => 'textfield',
      '#title' => t('Prefix'),
      '#default_value' => $settings[$element_name]['prefix'],
      '#size' => 60,
      '#description' => t("Define a string that should be prefixed to the value, like '$ ' or '&euro; '. Leave blank for none."),
    );
    $element[$element_name]['suffix'] = array(
      '#type' => 'textfield',
      '#title' => t('Suffix'),
      '#default_value' => $settings[$element_name]['suffix'],
      '#size' => 60,
      '#description' => t("Define a string that should be suffixed to the value, like ' m', ' kb/s'. Leave blank for none."),
    );

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    if (empty($this->from) && (string) $this->from !== '0' && empty($this->to) && (string) $this->to !== '0') {
      return TRUE;
    }
    return FALSE;
  }

}
