<?php

/**
 * @file
 * Contains \Drupal\range\Plugin\views\filter\Range.
 */

namespace Drupal\range\Plugin\views\filter;

use Drupal\views\Plugin\views\filter\FilterPluginBase;
use \Drupal\Component\Utility\String as UtilityString;

/**
 * Allows to filter view by value within a range.
 *
 * @ingroup views_filter_handlers
 *
 * @PluginID("range_within")
 */
class RangeWithin extends FilterPluginBase {

  /**
   * {@inheritdoc}
   */
  protected $always_multiple = TRUE;

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();

    $options['operator'] = array('default' => 'within');
    $options['value'] = array('default' => '');
    $options['include_endpoints'] = array('default' => FALSE);

    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function operators() {
    $operators = array(
      'within' => array(
        'title' => t('Range contains'),
        'short' => t('range contains'),
        'method' => 'opWithin',
        'values' => 1,
      ),
      'not within' => array(
        'title' => t('Range does not contain'),
        'short' => t('range does not contain'),
        'method' => 'opWithin',
        'values' => 1,
      ),
    );

    return $operators;
  }

  /**
   * {@inheritdoc}
   */
  public function operatorOptions($which = 'title') {
    $options = array();
    foreach ($this->operators() as $key => $value) {
      $options[$key] = $value[$which];
    }

    return $options;
  }

  /**
   * {@inheritdoc}
   */
  protected function operatorForm(&$form, &$form_state) {
    parent::operatorForm($form, $form_state);
    $form['include_endpoints'] = array(
      '#type' => 'checkbox',
      '#title' => t('Include endpoints'),
      '#default_value' => $this->options['include_endpoints'],
      '#description' => t('Whether or not include endpoints into the query.')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function valueForm(&$form, &$form_state) {
    $form['value'] = array(
      '#type' => 'textfield',
      '#title' => empty($form_state['exposed']) ? t('Value') : '',
      '#size' => 30,
      '#default_value' => $this->value,
    );
  }

  /**
   * {@inheritdoc}
   */
  function query() {
    $this->ensureMyTable();
    $field_from = $this->tableAlias . '.' . $this->definition['additional fields']['from'];
    $field_to = $this->tableAlias . '.' . $this->definition['additional fields']['to'];

    $info = $this->operators();
    if (!empty($info[$this->operator]['method'])) {
      $this->{$info[$this->operator]['method']}($field_from, $field_to);
    }
  }

  /**
   * Operation callback.
   */
  function opWithin($field_from, $field_to) {
    $operators = array(
      '<', '>',
      '<=', '>=',
    );

    $inlude_endpoints = !($this->options['include_endpoints'] xor ($this->operator == 'within'));
    list($op_left, $op_right) = array_slice($operators, $inlude_endpoints ? 2 : 0, 2);

    if ($this->operator == 'within') {
      $this->query->addWhere($this->options['group'], db_and()->condition($field_from, $this->value, $op_left)->condition($field_to, $this->value, $op_right));
    }
    else {
      $this->query->addWhere($this->options['group'], db_or()->condition($field_from, $this->value, $op_right)->condition($field_to, $this->value, $op_left));
    }
  }

  /**
   * {@inheritdoc}
   */
  function adminSummary() {
    if ($this->isAGroup()) {
      return t('grouped');
    }
    if (!empty($this->options['exposed'])) {
      return t('exposed');
    }

    $options = $this->operatorOptions('short');
    $output = UtilityString::checkPlain($options[$this->operator]) . ' ' . UtilityString::checkPlain($this->value);

    return $output;
  }

}
