<?php

use Drupal\Core\Entity\EntityStorageControllerInterface;
use Drupal\Core\Entity\FieldableDatabaseStorageController;

/**
 * @file
 * Provides views data for range.module.
 */

/**
 * Implements hook_views_data().
 */
function range_views_data() {
  $data = array();

  foreach (field_info_fields() as $field) {

    // Check the field module is range.
    if ($field->module != 'range') {
      continue;
    }
    // Check the field type is available.
    if (!\Drupal::service('plugin.manager.field.field_type')->getDefinition($field->getType())) {
      continue;
    }
    // Check the field has instances.
    if (!$field->getBundles()) {
      continue;
    }

    $field_name = $field->getName();
    $field_columns = $field->getColumns();

    // Grab information about the entity type tables.
    $entity_manager = \Drupal::entityManager();
    $entity_type_id = $field->entity_type;
    $entity_type = $entity_manager->getDefinition($entity_type_id);
    if (!$entity_table = $entity_type->getBaseTable()) {
      continue;
    }
    $entity_tables = array($entity_table => $entity_type_id);
    $entity_revision_table = $entity_type->getRevisionTable();
    $supports_revisions = $entity_type->hasKey('revision') && $entity_revision_table;
    if ($supports_revisions) {
      $entity_tables[$entity_revision_table] = $entity_type_id;
    }

    // Description of the field tables.
    $field_tables = array(
      EntityStorageControllerInterface::FIELD_LOAD_CURRENT => array(
        'table' => FieldableDatabaseStorageController::_fieldTableName($field),
        'alias' => "{$entity_type_id}__{$field_name}",
      ),
    );
    if ($supports_revisions) {
      $field_tables[EntityStorageControllerInterface::FIELD_LOAD_REVISION] = array(
        'table' => FieldableDatabaseStorageController::_fieldRevisionTableName($field),
        'alias' => "{$entity_type_id}_revision__{$field_name}",
      );
    }

    $add_fields = array();
    foreach (array_keys($field_columns) as $column) {
      $add_fields[$column] = FieldableDatabaseStorageController::_fieldColumnName($field, $column);
    }

    // Determine the label to use for the field. We don't have a label available
    // at the field level, so we just go through all instances and take the one
    // which is used the most frequently.
    list($label) = field_views_field_label($entity_type_id, $field_name);

    $base = array(
      'id' => 'range_within',
      'additional fields' => $add_fields,
      'field_name' => $field_name,
      'entity_type' => $entity_type_id,
      'allow empty' => FALSE,
    );

    // Build the relationships between the field table and the entity tables.
    $table = $field_tables[EntityStorageControllerInterface::FIELD_LOAD_CURRENT]['table'];
    $table_alias = $field_tables[EntityStorageControllerInterface::FIELD_LOAD_CURRENT]['alias'];
    $field_alias = $field_name;

    $data[$table_alias][$field_alias]['filter'] = array(
      'title' => t('@label range filter', array('@label' => $label)),
      'table' => $table,
      'field' => $field_alias,
    ) + $base;

    if ($supports_revisions) {
      $table = $field_tables[EntityStorageControllerInterface::FIELD_LOAD_REVISION]['table'];
      $table_alias = $field_tables[EntityStorageControllerInterface::FIELD_LOAD_REVISION]['alias'];
      $field_alias = $field_name . '-revision_id';

      $data[$table_alias][$field_alias]['filter'] = array(
        'title' => t('@label range filter (historical data)', array('@label' => $label)),
        'table' => $table,
        'field' => $field_alias,
      ) + $base;
    }

  }

  return $data;
}
